/*******************************************************************************
* File Name: DDS_ISR_Phase.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <DDS_ISR_Phase.h>

#if !defined(DDS_ISR_Phase__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START DDS_ISR_Phase_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: DDS_ISR_Phase_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void DDS_ISR_Phase_Start(void)
{
    /* For all we know the interrupt is active. */
    DDS_ISR_Phase_Disable();

    /* Set the ISR to point to the DDS_ISR_Phase Interrupt. */
    DDS_ISR_Phase_SetVector(&DDS_ISR_Phase_Interrupt);

    /* Set the priority. */
    DDS_ISR_Phase_SetPriority((uint8)DDS_ISR_Phase_INTC_PRIOR_NUMBER);

    /* Enable it. */
    DDS_ISR_Phase_Enable();
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void DDS_ISR_Phase_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    DDS_ISR_Phase_Disable();

    /* Set the ISR to point to the DDS_ISR_Phase Interrupt. */
    DDS_ISR_Phase_SetVector(address);

    /* Set the priority. */
    DDS_ISR_Phase_SetPriority((uint8)DDS_ISR_Phase_INTC_PRIOR_NUMBER);

    /* Enable it. */
    DDS_ISR_Phase_Enable();
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void DDS_ISR_Phase_Stop(void)
{
    /* Disable this interrupt. */
    DDS_ISR_Phase_Disable();

    /* Set the ISR to point to the passive one. */
    DDS_ISR_Phase_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for DDS_ISR_Phase.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(DDS_ISR_Phase_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START DDS_ISR_Phase_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling DDS_ISR_Phase_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use DDS_ISR_Phase_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void DDS_ISR_Phase_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)DDS_ISR_Phase__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress DDS_ISR_Phase_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)DDS_ISR_Phase__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling DDS_ISR_Phase_Start
*   or DDS_ISR_Phase_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   DDS_ISR_Phase_Start or DDS_ISR_Phase_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void DDS_ISR_Phase_SetPriority(uint8 priority)
{
    *DDS_ISR_Phase_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 DDS_ISR_Phase_GetPriority(void)
{
    uint8 priority;


    priority = *DDS_ISR_Phase_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void DDS_ISR_Phase_Enable(void)
{
    /* Enable the general interrupt. */
    *DDS_ISR_Phase_INTC_SET_EN = DDS_ISR_Phase__INTC_MASK;
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 DDS_ISR_Phase_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*DDS_ISR_Phase_INTC_SET_EN & (uint32)DDS_ISR_Phase__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void DDS_ISR_Phase_Disable(void)
{
    /* Disable the general interrupt. */
    *DDS_ISR_Phase_INTC_CLR_EN = DDS_ISR_Phase__INTC_MASK;
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void DDS_ISR_Phase_SetPending(void)
{
    *DDS_ISR_Phase_INTC_SET_PD = DDS_ISR_Phase__INTC_MASK;
}


/*******************************************************************************
* Function Name: DDS_ISR_Phase_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void DDS_ISR_Phase_ClearPending(void)
{
    *DDS_ISR_Phase_INTC_CLR_PD = DDS_ISR_Phase__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
